//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 2000  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// ImageLabel class - displays an ImageLabel graphic
//
import java.awt.Canvas;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Frame;
import java.awt.BorderLayout;
import java.awt.Image;
import java.awt.image.ImageProducer;

/**
 * Displays an ImageLabel graphic.
 */
public class ImageLabel extends Canvas {

	// image dimensions
	private Dimension	pref_size;//	= null;

	// image displayed in the label
	private Image		image;//	= null;


	/**
	 * Create a new ImageLabel.
	 */
	public ImageLabel() {
		super();
	}

	/**
	 * Create a new ImageLabel initialized with the given image.
	 */
	public ImageLabel( Image image ) {
		this();
		set_image( image );
	}

	/**
	 * Create a new ImageLabel initialized with the given ImageProducer.
	 */
	public ImageLabel( ImageProducer imageproducer ) {
		this();
		set_image( createImage( imageproducer ));
	}

	/*
	 * Return dimensions.
	 */
	public Dimension getPreferredSize() { return ( pref_size ); }
	public Dimension getMinimumSize() { return ( pref_size ); }

	/*
	 * Standard get/set methods.
	 */
	public Image get_image() { return ( image ); }
	public void set_image( Image image ) {
		this.image	= image;
		pref_size	= new Dimension( image.getWidth( this ),
						 image.getHeight( this ) );
		repaint();
	}

	/*
	 * Grey out a region of the graphics context.
	 */
	private void grey_out( Graphics g, int sx, int sy, int dx, int dy ) {

		// set the colour to background
		g.setColor( getBackground() );

		// pass over the region, resetting alternate pixels
		boolean speckle = false;
		for ( int y = sy; y < sy + dy; y++ ) {
			speckle = ( y % 2 == 0 );
			for ( int x = sx; x < sx + dx; x++ ) {
				if ( speckle )
					g.fillRect( x, y, 1, 1 );
				speckle = ! speckle;
			}
		}
	}

	/**
	 * Update (repaint) the graphic.
	 */
	public void update( Graphics g ) {
		Dimension d = getSize();

		// calculate the plot origin
		int x_orig = ( d.width  - pref_size.width  ) / 2;
		int y_orig = ( d.height - pref_size.height ) / 2;

		// draw the image
		g.drawImage( image, x_orig, y_orig, this );

		// now grey out the image if we are set insensitive
		if ( ! isEnabled() )
			grey_out( g, x_orig, y_orig,
					pref_size.width, pref_size.height );

	}

	/**
	 * Update the graphic.
	 */
	public void paint( Graphics g ) { update( g ); }


	/**
	 * Intercept calls to enable and disable to prompt repaint.
	 */
	public void setEnabled( boolean enabled ) {
		super.setEnabled( enabled ); repaint();
	}


	/**
	 * Class test code.
	 */
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		ImageLabel l = new ImageLabel(
				Xpm.get_image_producer( "PenguinA48x48" ));
		Frame frame = new Frame();
		frame.setLayout( new BorderLayout() );
		frame.add( "Center", l );
		frame.pack(); frame.setVisible( true );
		try { Thread.sleep( 5000 ); }
		catch ( Exception e ) {}
		l.setEnabled( false );
	}
}
